pub struct PhysicalIoHelper {
pub expr: Arc<dyn PhysicalExpr>,
pub has_window_function: bool,
}Expand description
Wrapper struct that allow us to use a PhysicalExpr in polars-io.
This is used to filter rows during the scan of file.
Fields
expr: Arc<dyn PhysicalExpr>has_window_function: boolTrait Implementations
Sourceimpl PhysicalIoExpr for PhysicalIoHelper
impl PhysicalIoExpr for PhysicalIoHelper
Sourcefn evaluate_io(&self, df: &DataFrame) -> PolarsResult<Series>
fn evaluate_io(&self, df: &DataFrame) -> PolarsResult<Series>